@@ -25,7 +25,7 @@ vetiver_pin_write(model_board, v)
 
 library(plumber)
 pr() %>%
-    vetiver_pr_predict(v, type = "class", debug = TRUE)
+    vetiver_api(v, type = "class", debug = TRUE)
 ## next pipe to pr_run(port = 8088) to see visual documentation
 
 vetiver_write_plumber(model_board, "biv_svm", file = "inst/plumber/biv-svm/plumber.R")
