@@ -33,7 +33,7 @@ test_that("can pin a tidymodels model", {
     expect_equal(
         pinned,
         list(
-            model = butcher::butcher(mtcars_wf),
+            model = bundle::bundle(butcher::butcher(mtcars_wf)),
             ptype = vctrs::vec_slice(tibble::as_tibble(mtcars[,2:11]), 0),
             required_pkgs = c("parsnip", "ranger", "workflows")
         )
@@ -64,7 +64,7 @@ test_that("default OpenAPI spec", {
 
 })
 
-test_that("create plumber.R for xgboost", {
+test_that("create plumber.R for tidymodels", {
     skip_on_cran()
     b <- board_folder(path = tmp_dir)
     vetiver_pin_write(b, v)
